curies |release| Documentation
==============================
Installation
------------
The most recent release can be installed from
`PyPI <https://pypi.org/project/curies>`_ with:

.. code-block:: shell

    $ pip install curies

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/cthoyt/curies.git

This package currently supports both Pydantic v1 and v2. See the
`Pydantic migration guide <https://docs.pydantic.dev/2.0/migration>`_
for updating your code.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   struct
   api
   resolver_service
   mapping_service
   cli
